@@ -1,5 +1,5 @@
 package Win32::VBScript;
-$Win32::VBScript::VERSION = '0.03';
+$Win32::VBScript::VERSION = '0.04';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ our @ISA         = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [qw(
     compile_prog_vbs compile_prog_js
     compile_func_vbs compile_func_js
-    cscript wscript func flist
+    cscript wscript async func flist
 )]);
 our @EXPORT      = qw();
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
